Create a clustering visualization app with the Bokeh server and
[scikit-learn](http://scikit-learn.org/stable/).

#### Setting Up

This demo requires the scikit-learn package in order to run. To install
scikit-learn using conda, execute the command:

    conda install scikit-learn

To install using pip, execute the command:

    pip install scikit-learn

#### Running


To view the app directly from a Bokeh server, navigate to the parent
directory [`examples/app`]([`examples/app`](https://github.com/bokeh/bokeh/tree/master/examples/app)),
and execute the command:

    bokeh serve --show clustering
